Learn R Programming

qtl (version 1.13-7)

summary.scanoneperm: LOD thresholds from scanone permutation results

Description

Print the estimated genome-wide LOD thresholds on the basis of permutation results from scanone (with n.perm > 0).

Usage

## S3 method for class 'scanoneperm':
summary(object, alpha=c(0.05, 0.10), df=FALSE, ...)

Arguments

object
Output from the function scanone with n.perm > 0.
alpha
Genome-wide significance levels.
df
If TRUE, the degrees of freedom associated with the LOD scores are shown.
...
Ignored at this point.

Value

  • An object of class summary.scanoneperm, to be printed by print.summary.scanoneperm. If there were X chromosome data and scanone was run with perm.Xsp=TRUE, there are two matrices in the results, for the autosome and X-chromosome LOD thresholds.

Details

If there were autosomal data only or scanone was run with perm.Xsp=FALSE, genome-wide LOD thresholds are given; these are the 1-$\alpha$ quantiles of the genome-wide maximum LOD scores from the permutations.

If there were autosomal and X chromosome data and scanone was run with perm.Xsp=TRUE, autosome- and X-chromsome-specific LOD thresholds are given, by the method described in Broman et al. (in press). Let $L_A$ and $L_X$ be total the genetic lengths of the autosomes and X chromosome, respectively, and let $L_T = L_A + L_X$ Then in place of $\alpha$, we use $$\alpha_A = 1 - (1-\alpha)^{L_A/L_T}$$ as the significance level for the autosomes and $$\alpha_X = 1 - (1-\alpha)^{L_X/L_T}$$ as the significance level for the X chromosome. The result is a list with two matrices, one for the autosomes and one for the X chromosome.

References

Broman, K. W., Sen, 'S, Owens, S. E., Manichaikul, A., Southard-Smith, E. M. and Churchill G. A. The X chromosome in quantitative trait locus mapping. Genetics, to appear.

Churchill, G. A. and Doerge, R. W. (1994) Empirical threshold values for quantitative trait mapping. Genetics 138, 963--971.

See Also

scanone, summary.scanone, plot.scanoneperm

Examples

Run this code
data(fake.f2)
fake.f2 <- subset(fake.f2, chr=c(18:19,"X"))
fake.f2 <- calc.genoprob(fake.f2, step=2.5)

operm1 <- scanone(fake.f2, n.perm=100, method="hk")
summary(operm1)

operm2 <- scanone(fake.f2, n.perm=100, method="hk", perm.Xsp=TRUE)
summary(operm2)

Run the code above in your browser using DataLab