powered by
find.pseudomarker(cross, chr, pos, where=c("draws", "prob"))
cross
read.cross
draws
prob
pos
chr
If multiple markers are exactly the same distance from the specified position, one is chosen at random from among those with the most genotype data.
For a cross with sex-specific maps, the input positions are assumed to correspond to the female genetic map.
find.flanking
plot.pxg
effectplot
find.marker
find.markerpos
data(listeria) listeria <- calc.genoprob(listeria, step=2.5) find.pseudomarker(listeria, 5, 28, "prob") find.pseudomarker(listeria, c(1, 5, 13), c(81, 28, 26), "prob")
Run the code above in your browser using DataLab