geno.table: Create table of genotype distributions
Description
Create table showing the observed numbers of individuals with each
genotype at each marker, including P-values from chi-square tests
for Mendelian segregation.
Usage
geno.table(cross, chr)
Arguments
cross
An object of class cross. See
read.cross for details.
chr
Optional vector indicating the chromosomes to consider.
This should be a vector of character strings referring to chromosomes
by name; numeric values are converted to strings. Refer to
chromosomes with a preceding - to have all chromos
Value
A matrix containing, for each marker, the number of individuals with
each possible genotype, as well as the number that were not typed.
The first column gives the chromosome ID, and the last column gives
P-values from chi-square tests of Mendelian segregation.
Details
The P-values are obtained from chi-square tests of Mendelian
segregation. In the case of the X chromosome, the sexes and cross
directions are tested separately, and the chi-square statistics
combined, and so the test is of whether any of the groups show
deviation from Mendel's rules.