Estimate the locations of crossovers for each individual on a given
chromosome.
Usage
locateXO(cross, chr)
Arguments
cross
An object of class cross. See
read.cross for details.
chr
Chromosome to investigate (if unspecified, the first
chromosome is considered).
This should be a character string referring to a chromosome
by name; numeric values are converted to strings.
Value
A list with one component per individual. Each component is either
NULL or is a numeric vector with the estimated crossover locations.
Details
For each individual we detemine the locations of obligate crossovers,
and estimate their location to be at the midpoint between the nearest
flanking typed markers.
The function currently only works for a backcross, intercross, or
recombinant inbred line.