plot.info(x, chr, method=c("both","entropy","variance"), step=1,
off.end=0, error.prob=0.001,
map.function=c("haldane","kosambi","c-f","morgan"),
alternate.chrid=FALSE, ...)cross. See
read.cross for details.- to have all chromosomesstep=0,
it is are calculated only at the marker locations.plot.scanone.scanone: a data.frame with columns the
chromosome IDs and cM positions followed by the entropy and/or
variance version of the missing information. Calculations are done in C (for the sake of speed in the presence of
little thought about programming efficiency) and the plot is created
by a call to plot.scanone.
Note that summary.scanone may be used to display
the maximum missing information on each chromosome.
plot.scanone,
plot.missingdata(hyper)
hyper <- subset(hyper,chr=1:4)
plot.info(hyper,chr=c(1,4))
# save the results and view maximum missing info on each chr
info <- plot.info(hyper)
summary(info)Run the code above in your browser using DataLab