Learn R Programming

qtl (version 1.13-7)

pull.map: Pull out the genetic map from a cross

Description

Pull out the map portion of a cross object.

Usage

pull.map(cross, chr)

Arguments

cross
An object of class cross. See read.cross for details.
chr
Optional vector indicating the chromosomes to consider. This should be a vector of character strings referring to chromosomes by name; numeric values are converted to strings. Refer to chromosomes with a preceding - to have all chromos

Value

  • The genetic map: a list with each component containing the marker positions (in cM) for a chromosome. Each component has class A or X according to whether it is an autosome or the X chromosome. The components are either vectors of marker positions or, for a sex-specific map, 2-row matrices containing the female and male marker locations. The map itself is given class map.

See Also

replace.map, plot.map

Examples

Run this code
data(fake.f2)
map <- pull.map(fake.f2)
plot(map)

Run the code above in your browser using DataLab