sim.geno(cross, n.draws=16, step=0, off.end=0, error.prob=0.0001,
map.function=c("haldane","kosambi","c-f","morgan"))cross. See
read.cross for details.step = 0,
genotypes are drawn only at the marker locations.cross object is returned with a component,
draws, added to each component of cross$geno.
draws is array of size [n.ind x n.pos x n.draws] where n.pos is
the number of positions at which the simulations were performed and
n.draws is the number of replicates. Attributes "error.prob",
"step", and "off.end" are set to the values of the
corresponding arguments, for later reference.In the case of the 4-way cross, with a sex-specific map, we assume a constant ratio of female:male recombination rates within the inter-marker intervals.
calc.genoprob,
argmax.genodata(fake.f2)
fake.f2 <- subset(fake.f2, chr=18:19)
fake.f2 <- sim.geno(fake.f2, step=2, n.draws=8)Run the code above in your browser using DataLab